# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: Media.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import Audio_pb2 as Audio__pb2
import Emoticon_pb2 as Emoticon__pb2
import File_pb2 as File__pb2
import Image_pb2 as Image__pb2
import Video_pb2 as Video__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0bMedia.proto\x12\x1b\x41\x63\x46unDanmu.Im.Cloud.Message\x1a\x0b\x41udio.proto\x1a\x0e\x45moticon.proto\x1a\nFile.proto\x1a\x0bImage.proto\x1a\x0bVideo.proto\"\xbb\x02\n\x05Media\x12\x33\n\x05image\x18\x01 \x01(\x0b\x32\".AcFunDanmu.Im.Cloud.Message.ImageH\x00\x12\x33\n\x05\x61udio\x18\x02 \x01(\x0b\x32\".AcFunDanmu.Im.Cloud.Message.AudioH\x00\x12\x33\n\x05video\x18\x03 \x01(\x0b\x32\".AcFunDanmu.Im.Cloud.Message.VideoH\x00\x12\x31\n\x04\x66ile\x18\x04 \x01(\x0b\x32!.AcFunDanmu.Im.Cloud.Message.FileH\x00\x12\x39\n\x08\x65moticon\x18\x05 \x01(\x0b\x32%.AcFunDanmu.Im.Cloud.Message.EmoticonH\x00\x12\x0b\n\x03pos\x18\x14 \x01(\x05\x12\x0c\n\x04name\x18\x15 \x01(\tB\n\n\x08resourceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'Media_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _MEDIA._serialized_start=112
  _MEDIA._serialized_end=427
# @@protoc_insertion_point(module_scope)



"""Module for encoding and decoding length delimited fields"""
import sys
import copy
from google.protobuf.internal import wire_format, encoder, decoder
from . import varint, type_maps


def decode_guess(buf, pos):
    """Try to decode as an empty message first, then just do as bytes
       Returns the value + the type"""
    try:
        return decode_lendelim_message(buf, {}, pos), 'message'
    except Exception as exc:
        return decode_bytes(buf, pos), 'bytes'


def encode_bytes(value):
    """Encode varint length followed by the string"""
    if isinstance(value, str):
        value = bytearray(value, 'utf-8')
    else:
        value = bytearray(value)
    encoded_length = varint.encode_varint(len(value))
    return encoded_length + value


def decode_bytes(value, pos):
    """Decode varint for length and then the bytes"""
    length, pos = varint.decode_varint(value, pos)
    end = pos + length
    return value[pos:end], end


def decode_str(value, pos):
    """Decode varint for length and then the string"""
    length, pos = varint.decode_varint(value, pos)
    end = pos + length
    return value[pos:end].decode('utf-8', 'backslashreplace'), end


def encode_message(data, typedef, group=False):
    """Encode a Python dictionary representing a protobuf message
       data - Python dictionary mapping field numbers to values
       typedef - Type information including field number, field name and field type
       This will throw an exception if an unkown value is used as a key
    """
    output = bytearray()

    for field_number, value in data.items():
        # Get the field number convert it as necessary
        alt_field_number = None
        if isinstance(field_number, str):
            if '-' in field_number:
                field_number, alt_field_number = field_number.split('-')
            for number, info in typedef.items():
                if info['name'] == field_number and field_number != '':
                    field_number = number
                    break
        else:
            field_number = str(field_number)

        if field_number not in typedef:
            raise ValueError('Provided field name/number %s is not valid'
                             % (field_number))

        field_typedef = typedef[field_number]

        # Get encoder
        if 'type' not in field_typedef:
            raise ValueError('Field %s does not have a defined type' % field_number)

        field_type = field_typedef['type']

        field_encoder = None
        if field_type == 'message':
            innertypedef = None
            # Check for a defined message type
            if alt_field_number is not None:
                if alt_field_number not in field_typedef['alt_typedefs']:
                    raise ValueError(
                        'Provided alt field name/number %s is not valid for field_number %s'
                        % (alt_field_number, field_number))
                innertypedef = field_typedef['alt_typedefs'][alt_field_number]
            elif 'message_typedef' in field_typedef:
                # "Anonymous" inner message
                # Required to have a 'message_typedef'
                if 'message_typedef' not in field_typedef:
                    raise ValueError('Could not find type definition for message field: %s'
                                     % field_number)
                innertypedef = field_typedef['message_typedef']
            else:
                if field_typedef['message_type_name'] not in acfunsdk.libs.blackboxprotobuf.libs.known_messages:
                    raise ValueError('Message type (%s) has not been defined'
                                     % field_typedef['message_type_name'])
                innertypedef = field_typedef['message_type_name']

            field_encoder = lambda data: encode_lendelim_message(data, innertypedef)
        elif field_type == 'group':
            innertypedef = None
            # Check for a defined group type
            if 'group_typedef' not in field_typedef:
                raise ValueError('Could not find type definition for group field: %s'
                                 % field_number)
            innertypedef = field_typedef['group_typedef']

            field_encoder = lambda data: encode_group(data, innertypedef, field_number)
        else:
            if field_type not in type_maps.encoders:
                raise ValueError('Unknown type: %s' % field_type)
            field_encoder = type_maps.encoders[field_type]
            if field_encoder is None:
                raise ValueError('Encoder not implemented: %s' % field_type)

        # Encode the tag
        tag = encoder.TagBytes(int(field_number), type_maps.wiretypes[field_type])

        try:
            # Handle repeated values
            if isinstance(value, list) and not field_type.startswith('packed_'):
                for repeated in value:
                    output += tag
                    output += field_encoder(repeated)
            else:
                output += tag
                output += field_encoder(value)
        except Exception as exc:
            raise ValueError(
                'Error attempting to encode "%s" as %s: %s'
                % (value, field_type, exc), sys.exc_info()[2])

    return output


def decode_message(buf, typedef=None, pos=0, end=None, group=False):
    """Decode a protobuf message with no length delimiter"""
    if end is None:
        end = len(buf)

    if typedef is None:
        typedef = {}
    else:
        # Don't want to accidentally modify the original
        typedef = copy.deepcopy(typedef)

    output = {}

    while pos < end:
        # Read in a field
        tag, pos = decoder._DecodeVarint(buf, pos)
        try:
            field_number, wire_type = wire_format.UnpackTag(tag)
        except Exception as exc:
            raise (ValueError,
                   'Could not read valid tag at pos %d. Ensure it is a valid protobuf message: %s'
                   % (pos - len(tag), exc), sys.exc_info()[2])

        # Convert to str
        field_number = str(field_number)
        orig_field_number = field_number

        field_typedef = None
        if field_number in typedef:
            field_typedef = typedef[field_number]
        else:
            field_typedef = {}
            field_typedef['type'] = type_maps.wire_type_defaults[wire_type]

        field_type = field_typedef['type']

        # If field_type is None, its either an unsupported wire type, length delim or group
        # length delim we have to try and decode first
        field_out = None
        if field_type is None:
            if wire_type == wire_format.WIRETYPE_LENGTH_DELIMITED:
                out, field_type = decode_guess(buf, pos)
                if field_type == 'message':
                    field_out, message_typedef, pos = out
                    field_typedef['message_typedef'] = message_typedef
                else:
                    field_out, pos = out
            elif wire_type == wire_format.WIRETYPE_END_GROUP:
                # TODO Should probably match the field_number to START_GROUP
                if not group:
                    raise ValueError("Found END_GROUP before START_GROUP")
                # exit out
                return output, typedef, pos
            else:
                raise ValueError("Could not find default type for wiretype: %d" % wire_type)
        else:
            if field_type == 'message':
                # TODO probably big enough to factor out
                message_typedef = None
                # Check for a anonymous type
                if 'message_typedef' in field_typedef:
                    message_typedef = field_typedef['message_typedef']
                # Check for type defined by message type name
                elif 'message_type_name' in field_typedef:
                    message_typedef = type_maps.messages[
                        field_typedef['message_type_name']]

                try:
                    field_out, message_typedef, pos = decode_lendelim_message(
                        buf, message_typedef, pos)
                    # Save type definition
                    field_typedef['message_typedef'] = message_typedef
                except Exception as exc:
                    # If this is the root message just fail
                    if pos == 0:
                        raise exc

                if field_out is None and 'alt_typedefs' in field_typedef:
                    # check for an alternative type definition
                    for alt_field_number, alt_typedef in field_typedef['alt_typedefs'].items():
                        try:
                            field_out, message_typedef, pos = decode_lendelim_message(
                                buf, alt_typedef, pos)
                        except Exception as exc:
                            pass

                        if field_out is not None:
                            # Found working typedef
                            field_typedef['alt_typedefs'][alt_field_number] = message_typedef
                            field_number = field_number + "-" + alt_field_number
                            break

                if field_out is None:
                    # Still no typedef, try anonymous, and let the error propogate if it fails
                    field_out, message_typedef, pos = decode_lendelim_message(buf, {}, pos)
                    if 'alt_typedefs' in field_typedef:
                        # get the next higher alt field number
                        alt_field_number = str(
                            max(map(int, field_typedef['alt_typedefs'].keys()))
                            + 1)
                    else:
                        field_typedef['alt_typedefs'] = {}
                        alt_field_number = '1'

                    field_typedef['alt_typedefs'][alt_field_number] = message_typedef
                    field_number = field_number + "-" + alt_field_number
            elif field_type == 'group':
                group_typedef = None
                # Check for a anonymous type
                if 'group_typedef' in field_typedef:
                    group_typedef = field_typedef['group_typedef']
                field_out, group_typedef, pos = decode_group(buf, group_typedef, pos)
                # Save type definition
                field_typedef['group_typedef'] = group_typedef
            else:
                # Verify wiretype matches
                if type_maps.wiretypes[field_type] != wire_type:
                    raise ValueError("Invalid wiretype for field number %s. %s is not wiretype %s"
                                     % (field_number, field_type, wire_type))

                # Simple type, just look up the decoder
                field_out, pos = type_maps.decoders[field_type](buf, pos)
        field_typedef['type'] = field_type
        if 'name' not in field_typedef:
            field_typedef['name'] = ''

        field_key = field_number
        if '-' not in field_number and 'name' in field_typedef and field_typedef['name'] != '':
            field_key = field_typedef['name']
        # Deal with repeats
        if field_key in output:
            if isinstance(field_out, list):
                if isinstance(output[field_number], list):
                    output[field_key] += field_out
                else:
                    output[field_key] = field_out.append(output[field_key])
            else:
                if isinstance(output[field_number], list):
                    output[field_key].append(field_out)
                else:
                    output[field_key] = [output[field_key], field_out]
        else:
            output[field_key] = field_out
            typedef[orig_field_number] = field_typedef
    if pos > end:
        raise decoder._DecodeError("Invalid Message Length")
    # Should never hit here as a group
    if group:
        raise ValueError("Got START_GROUP with no END_GROUP.")
    return output, typedef, pos


def encode_lendelim_message(data, typedef):
    """Encode the length before the message"""
    message_out = encode_message(data, typedef)
    length = varint.encode_varint(len(message_out))
    return length + message_out


def decode_lendelim_message(buf, typedef=None, pos=0):
    """Read in the length and use it as the end"""
    length, pos = varint.decode_varint(buf, pos)
    ret = decode_message(buf, typedef, pos, pos + length)
    return ret


# Not actually length delim, but we're hijacking the methods anyway
def encode_group(value, typedef, field_number):
    """Encode a protobuf group type"""
    # Message will take care of the start tag
    # Need to add the end_tag
    output = encode_message(value, typedef, group=True)
    end_tag = encoder.TagBytes(int(field_number), wire_format.WIRETYPE_END_GROUP)
    output.append(end_tag)
    return output


def decode_group(buf, typedef=None, pos=0, end=None):
    """Decode a protobuf group type"""
    return decode_message(buf, typedef, pos, end, group=True)


def generate_packed_encoder(wrapped_encoder):
    """Generate an encoder for a packed type from the base type encoder"""

    def length_wrapper(values):
        """Encode repeat values and prefix with the length"""
        output = bytearray()
        for value in values:
            output += wrapped_encoder(value)
        length = varint.encode_varint(len(output))
        return length + output

    return length_wrapper


def generate_packed_decoder(wrapped_decoder):
    """Generate an decoder for a packer type from a base type decoder"""

    def length_wrapper(buf, pos):
        """Decode repeat values prefixed with the length"""
        length, pos = varint.decode_varint(buf, pos)
        end = pos + length
        output = []
        while pos < end:
            value, pos = wrapped_decoder(buf, pos)
            output.append(value)
        if pos > end:
            raise decoder._DecodeError("Invalid Packed Field Length")
        return output, pos

    return length_wrapper



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: RichTextNoticeMessage.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bRichTextNoticeMessage.proto\x12\x15\x41\x63\x46unDanmu.Im.Message\"\xc4\x01\n\x15RichTextNoticeMessage\x12H\n\x05items\x18\x01 \x03(\x0b\x32\x39.AcFunDanmu.Im.Message.RichTextNoticeMessage.RichTextItem\x1a\x61\n\x0cRichTextItem\x12\r\n\x05\x63olor\x18\x01 \x01(\x05\x12\r\n\x05start\x18\x02 \x01(\x05\x12\x0b\n\x03len\x18\x03 \x01(\x05\x12\x13\n\x0b\x63lickAction\x18\x04 \x01(\t\x12\x11\n\tunderline\x18\x05 \x01(\x08\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'RichTextNoticeMessage_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _RICHTEXTNOTICEMESSAGE._serialized_start=55
  _RICHTEXTNOTICEMESSAGE._serialized_end=251
  _RICHTEXTNOTICEMESSAGE_RICHTEXTITEM._serialized_start=154
  _RICHTEXTNOTICEMESSAGE_RICHTEXTITEM._serialized_end=251
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: MessageSearchRequest.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import ChatTarget_pb2 as ChatTarget__pb2
import ImcMessageType_pb2 as ImcMessageType__pb2
import TimeFilter_pb2 as TimeFilter__pb2
import User_pb2 as User__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1aMessageSearchRequest.proto\x12\x1a\x41\x63\x46unDanmu.Im.Cloud.Search\x1a\x10\x43hatTarget.proto\x1a\x14ImcMessageType.proto\x1a\x10TimeFilter.proto\x1a\nUser.proto\"\xed\x02\n\x14MessageSearchRequest\x12\x35\n\nchatTarget\x18\x01 \x01(\x0b\x32!.AcFunDanmu.Im.Message.ChatTarget\x12\'\n\x04\x66rom\x18\x02 \x01(\x0b\x32\x19.AcFunDanmu.Im.Basic.User\x12<\n\x07msgType\x18\x03 \x03(\x0e\x32+.AcFunDanmu.Im.Cloud.Message.ImcMessageType\x12\x10\n\x08\x66ileName\x18\x04 \x03(\t\x12\r\n\x05query\x18\x05 \x03(\t\x12\x0e\n\x06offset\x18\x06 \x01(\t\x12:\n\ntimeFilter\x18\x07 \x01(\x0b\x32&.AcFunDanmu.Im.Cloud.Search.TimeFilter\x12\x1a\n\x12msgCountPerSession\x18\x08 \x01(\x05\x12\x13\n\x0bmessageType\x18\t \x03(\x05\x12\x19\n\x11searchAfterOffset\x18\n \x01(\x08\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'MessageSearchRequest_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _MESSAGESEARCHREQUEST._serialized_start=129
  _MESSAGESEARCHREQUEST._serialized_end=494
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: GroupSettingInvitePermission.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import InvitePermissionType_pb2 as InvitePermissionType__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"GroupSettingInvitePermission.proto\x12\x1b\x41\x63\x46unDanmu.Im.Cloud.Message\x1a\x1aInvitePermissionType.proto\"o\n\x1cGroupSettingInvitePermission\x12O\n\x14invitePermissionType\x18\x01 \x01(\x0e\x32\x31.AcFunDanmu.Im.Cloud.Message.InvitePermissionTypeb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'GroupSettingInvitePermission_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GROUPSETTINGINVITEPERMISSION._serialized_start=95
  _GROUPSETTINGINVITEPERMISSION._serialized_end=206
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: VoiceCallEventPush.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import User_pb2 as User__pb2
import VoiceCallAcceptedEvent_pb2 as VoiceCallAcceptedEvent__pb2
import VoiceCallAlreadyProcessedEvent_pb2 as VoiceCallAlreadyProcessedEvent__pb2
import VoiceCallCancelledEvent_pb2 as VoiceCallCancelledEvent__pb2
import VoiceCallClosedEvent_pb2 as VoiceCallClosedEvent__pb2
import VoiceCallDetailUpdateEvent_pb2 as VoiceCallDetailUpdateEvent__pb2
import VoiceCallRejectedEvent_pb2 as VoiceCallRejectedEvent__pb2
import VoiceCallRequestEvent_pb2 as VoiceCallRequestEvent__pb2
import VoiceCallTimeoutEvent_pb2 as VoiceCallTimeoutEvent__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18VoiceCallEventPush.proto\x12\x1e\x41\x63\x46unDanmu.Im.Cloud.Voice.Call\x1a\nUser.proto\x1a\x1cVoiceCallAcceptedEvent.proto\x1a$VoiceCallAlreadyProcessedEvent.proto\x1a\x1dVoiceCallCancelledEvent.proto\x1a\x1aVoiceCallClosedEvent.proto\x1a VoiceCallDetailUpdateEvent.proto\x1a\x1cVoiceCallRejectedEvent.proto\x1a\x1bVoiceCallRequestEvent.proto\x1a\x1bVoiceCallTimeoutEvent.proto\"\xfd\x05\n\x12VoiceCallEventPush\x12M\n\x0crequestEvent\x18\x14 \x01(\x0b\x32\x35.AcFunDanmu.Im.Cloud.Voice.Call.VoiceCallRequestEventH\x00\x12O\n\racceptedEvent\x18\x15 \x01(\x0b\x32\x36.AcFunDanmu.Im.Cloud.Voice.Call.VoiceCallAcceptedEventH\x00\x12O\n\rrejectedEvent\x18\x16 \x01(\x0b\x32\x36.AcFunDanmu.Im.Cloud.Voice.Call.VoiceCallRejectedEventH\x00\x12K\n\x0b\x63losedEvent\x18\x17 \x01(\x0b\x32\x34.AcFunDanmu.Im.Cloud.Voice.Call.VoiceCallClosedEventH\x00\x12Q\n\x0e\x63\x61ncelledEvent\x18\x18 \x01(\x0b\x32\x37.AcFunDanmu.Im.Cloud.Voice.Call.VoiceCallCancelledEventH\x00\x12_\n\x15\x61lreadyProcessedEvent\x18\x19 \x01(\x0b\x32>.AcFunDanmu.Im.Cloud.Voice.Call.VoiceCallAlreadyProcessedEventH\x00\x12M\n\x0ctimeoutEvent\x18\x1a \x01(\x0b\x32\x35.AcFunDanmu.Im.Cloud.Voice.Call.VoiceCallTimeoutEventH\x00\x12W\n\x11\x64\x65tailUpdateEvent\x18\x1b \x01(\x0b\x32:.AcFunDanmu.Im.Cloud.Voice.Call.VoiceCallDetailUpdateEventH\x00\x12\x0e\n\x06roomId\x18\x01 \x01(\t\x12+\n\x08operator\x18\x02 \x01(\x0b\x32\x19.AcFunDanmu.Im.Basic.UserB\x10\n\x0evoiceCallEventb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'VoiceCallEventPush_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _VOICECALLEVENTPUSH._serialized_start=322
  _VOICECALLEVENTPUSH._serialized_end=1087
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ImcNoticeMessage.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import NoticePlaceholderMeta_pb2 as NoticePlaceholderMeta__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16ImcNoticeMessage.proto\x12\x1b\x41\x63\x46unDanmu.Im.Cloud.Message\x1a\x1bNoticePlaceholderMeta.proto\"\xb9\x01\n\x10ImcNoticeMessage\x12\x0c\n\x04text\x18\x01 \x01(\t\x12Q\n\x15noticePlaceholderMeta\x18\x02 \x03(\x0b\x32\x32.AcFunDanmu.Im.Cloud.Message.NoticePlaceholderMeta\x12\x16\n\x0enoticeMetaType\x18\x03 \x01(\x05\x12\x16\n\x0enoticeMetaInfo\x18\x04 \x01(\x0c\x12\x14\n\x0c\x64isplayStyle\x18\x05 \x01(\x05\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ImcNoticeMessage_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _IMCNOTICEMESSAGE._serialized_start=85
  _IMCNOTICEMESSAGE._serialized_end=270
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: GroupJoinResponse.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17GroupJoinResponse.proto\x12\x1b\x41\x63\x46unDanmu.Im.Cloud.Message\"\x9b\x01\n\x11GroupJoinResponse\x12M\n\njoinStatus\x18\x01 \x01(\x0e\x32\x39.AcFunDanmu.Im.Cloud.Message.GroupJoinResponse.JoinStatus\"7\n\nJoinStatus\x12\x12\n\x0eUNKNOWN_STATUS\x10\x00\x12\x08\n\x04SUCC\x10\x01\x12\x0b\n\x07PENDING\x10\x02\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'GroupJoinResponse_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GROUPJOINRESPONSE._serialized_start=57
  _GROUPJOINRESPONSE._serialized_end=212
  _GROUPJOINRESPONSE_JOINSTATUS._serialized_start=157
  _GROUPJOINRESPONSE_JOINSTATUS._serialized_end=212
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: CloseVoiceCallRequest.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import User_pb2 as User__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x43loseVoiceCallRequest.proto\x12\x1e\x41\x63\x46unDanmu.Im.Cloud.Voice.Call\x1a\nUser.proto\"\xfc\x01\n\x15\x43loseVoiceCallRequest\x12\x0e\n\x06roomId\x18\x01 \x01(\t\x12Q\n\x06reason\x18\x02 \x01(\x0e\x32\x41.AcFunDanmu.Im.Cloud.Voice.Call.CloseVoiceCallRequest.CloseReason\x12+\n\x08nextHost\x18\x03 \x01(\x0b\x32\x19.AcFunDanmu.Im.Basic.User\"S\n\x0b\x43loseReason\x12\x0e\n\nCR_UNKNOWN\x10\x00\x12\n\n\x06NORMAL\x10\x01\x12\r\n\tCANCELLED\x10\x02\x12\x0b\n\x07TIMEOUT\x10\x03\x12\x0c\n\x08\x46INISHED\x10\x04\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'CloseVoiceCallRequest_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CLOSEVOICECALLREQUEST._serialized_start=76
  _CLOSEVOICECALLREQUEST._serialized_end=328
  _CLOSEVOICECALLREQUEST_CLOSEREASON._serialized_start=245
  _CLOSEVOICECALLREQUEST_CLOSEREASON._serialized_end=328
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: SystemSessionFolder.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19SystemSessionFolder.proto\x12!AcFunDanmu.Im.Cloud.SessionFolder*\x9e\x01\n\x13SystemSessionFolder\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x16\n\x12\x46OLDER_DISPATCHING\x10\x01\x12\x12\n\x0e\x46OLDER_SERVING\x10\x02\x12\x10\n\x0c\x46OLDER_REPLY\x10\x03\x12\x15\n\x11\x46OLDER_AUTO_REPLY\x10\x04\x12\x12\n\x0e\x46OLDER_TIMEOUT\x10\x05\x12\x11\n\rFOLDER_CLOSED\x10\x06\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'SystemSessionFolder_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SYSTEMSESSIONFOLDER._serialized_start=65
  _SYSTEMSESSIONFOLDER._serialized_end=223
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: Reference.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import Message_pb2 as Message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0fReference.proto\x12\x1b\x41\x63\x46unDanmu.Im.Cloud.Message\x1a\rMessage.proto\"\xc7\x01\n\tReference\x12\x31\n\toriginMsg\x18\x01 \x01(\x0b\x32\x1e.AcFunDanmu.Im.Message.Message\x12M\n\x0creferenceMsg\x18\x02 \x01(\x0b\x32\x37.AcFunDanmu.Im.Cloud.Message.Reference.ReferenceMessage\x1a\x38\n\x10ReferenceMessage\x12\x13\n\x0b\x63ontentType\x18\x01 \x01(\x05\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\x0c\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'Reference_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _REFERENCE._serialized_start=64
  _REFERENCE._serialized_end=263
  _REFERENCE_REFERENCEMESSAGE._serialized_start=207
  _REFERENCE_REFERENCEMESSAGE._serialized_end=263
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: CommonNotifySignalCoverAuditResult.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(CommonNotifySignalCoverAuditResult.proto\x12\nAcFunDanmu\"\xd4\x01\n\"CommonNotifySignalCoverAuditResult\x12O\n\x0b\x61uditStatus\x18\x01 \x01(\x0e\x32:.AcFunDanmu.CommonNotifySignalCoverAuditResult.AuditStatus\"]\n\x0b\x41uditStatus\x12\x0b\n\x07SUCCESS\x10\x00\x12\x16\n\x12\x43OVER_AUDIT_FAILED\x10\x01\x12\x18\n\x14\x43\x41PTION_AUDIT_FAILED\x10\x02\x12\x0f\n\x0b\x42OTH_FAILED\x10\x03\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'CommonNotifySignalCoverAuditResult_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMMONNOTIFYSIGNALCOVERAUDITRESULT._serialized_start=57
  _COMMONNOTIFYSIGNALCOVERAUDITRESULT._serialized_end=269
  _COMMONNOTIFYSIGNALCOVERAUDITRESULT_AUDITSTATUS._serialized_start=176
  _COMMONNOTIFYSIGNALCOVERAUDITRESULT_AUDITSTATUS._serialized_end=269
# @@protoc_insertion_point(module_scope)



""" Functions for encoding and decoding fixed size structs """
import struct


# Generic functions for encoding/decoding structs based on the "struct" format
def encode_struct(fmt, value):
    """Generic method for encoding arbitrary python "struct" values"""
    return struct.pack(fmt, value)


def decode_struct(fmt, buf, pos):
    """Generic method for decoding arbitrary python "struct" values"""
    new_pos = pos + struct.calcsize(fmt)
    return struct.unpack(fmt, buf[pos:new_pos])[0], new_pos


_fixed32_fmt = '<I'


def encode_fixed32(value):
    """Encode a single 32 bit fixed-size value"""
    return encode_struct(_fixed32_fmt, value)


def decode_fixed32(buf, pos):
    """Decode a single 32 bit fixed-size value"""
    return decode_struct(_fixed32_fmt, buf, pos)


_sfixed32_fmt = '<i'


def encode_sfixed32(value):
    """Encode a single signed 32 bit fixed-size value"""
    return encode_struct(_sfixed32_fmt, value)


def decode_sfixed32(buf, pos):
    """Decode a single signed 32 bit fixed-size value"""
    return decode_struct(_sfixed32_fmt, buf, pos)


_float_fmt = '<f'


def encode_float(value):
    """Encode a single 32 bit floating point value"""
    return encode_struct(_float_fmt, value)


def decode_float(buf, pos):
    """Decode a single 32 bit floating point value"""
    return decode_struct(_float_fmt, buf, pos)


_fixed64_fmt = '<Q'


def encode_fixed64(value):
    """Encode a single 64 bit fixed-size value"""
    return encode_struct(_fixed64_fmt, value)


def decode_fixed64(buf, pos):
    """Decode a single 64 bit fixed-size value"""
    return decode_struct(_fixed64_fmt, buf, pos)


_sfixed64_fmt = '<q'


def encode_sfixed64(value):
    """Encode a single signed 64 bit fixed-size value"""
    return encode_struct(_sfixed64_fmt, value)


def decode_sfixed64(buf, pos):
    """Decode a single signed 64 bit fixed-size value"""
    return decode_struct(_sfixed64_fmt, buf, pos)


_double_fmt = '<d'


def encode_double(value):
    """Encode a single 64 bit floating point value"""
    return encode_struct(_double_fmt, value)


def decode_double(buf, pos):
    """Decode a single 64 bit floating point value"""
    return decode_struct(_double_fmt, buf, pos)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: Audio.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0b\x41udio.proto\x12\x1b\x41\x63\x46unDanmu.Im.Cloud.Message\"K\n\x05\x41udio\x12\x0b\n\x03uri\x18\x01 \x01(\t\x12\x10\n\x08\x64uration\x18\x02 \x01(\x05\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x15\n\rcontentLength\x18\x04 \x01(\x03\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'Audio_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _AUDIO._serialized_start=44
  _AUDIO._serialized_end=119
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: VisibleAmountRequest.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1aVisibleAmountRequest.proto\x12\x15\x41\x63\x46unDanmu.Im.Message\"K\n\x14VisibleAmountRequest\x12\x0e\n\x06minSeq\x18\x01 \x01(\x03\x12\x0e\n\x06maxSeq\x18\x02 \x01(\x03\x12\x13\n\x0bstrTargetId\x18\x06 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'VisibleAmountRequest_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _VISIBLEAMOUNTREQUEST._serialized_start=53
  _VISIBLEAMOUNTREQUEST._serialized_end=128
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ZtLiveCsHeartbeat.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17ZtLiveCsHeartbeat.proto\x12\nAcFunDanmu\"@\n\x11ZtLiveCsHeartbeat\x12\x19\n\x11\x63lientTimestampMs\x18\x01 \x01(\x03\x12\x10\n\x08sequence\x18\x02 \x01(\x03\"d\n\x14ZtLiveCsHeartbeatAck\x12\x19\n\x11serverTimestampMs\x18\x01 \x01(\x03\x12\x19\n\x11\x63lientTimestampMs\x18\x02 \x01(\x03\x12\x16\n\x0e\x63lientSequence\x18\x03 \x01(\x03\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ZtLiveCsHeartbeat_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ZTLIVECSHEARTBEAT._serialized_start=39
  _ZTLIVECSHEARTBEAT._serialized_end=103
  _ZTLIVECSHEARTBEATACK._serialized_start=105
  _ZTLIVECSHEARTBEATACK._serialized_end=205
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ZtLiveDownstreamPayloadErrorCode.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&ZtLiveDownstreamPayloadErrorCode.proto\x12\nAcFunDanmu*\x97\x01\n ZtLiveDownstreamPayloadErrorCode\x12\x1e\n\x1aSUCCESS_DOWNSTREAM_PAYLOAD\x10\x00\x12\x18\n\x12\x43S_CMD_PARSE_ERROR\x10\xa1\x8d\x06\x12\x1c\n\x16\x43S_CMD_CMD_NOT_SUPPORT\x10\xa2\x8d\x06\x12\x1b\n\x15\x43S_CMD_TICKET_ILLEGAL\x10\xa3\x8d\x06\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ZtLiveDownstreamPayloadErrorCode_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ZTLIVEDOWNSTREAMPAYLOADERRORCODE._serialized_start=55
  _ZTLIVEDOWNSTREAMPAYLOADERRORCODE._serialized_end=206
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: CommentNotice.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import Button_pb2 as Button__pb2
import ClickEvent_pb2 as ClickEvent__pb2
import ImageCdnNode_pb2 as ImageCdnNode__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13\x43ommentNotice.proto\x12\nAcFunDanmu\x1a\x0c\x42utton.proto\x1a\x10\x43lickEvent.proto\x1a\x12ImageCdnNode.proto\"\xfe\x01\n\rCommentNotice\x12\t\n\x01\x61\x18\x01 \x01(\t\x12\t\n\x01\x62\x18\x02 \x01(\x0c\x12\t\n\x01\x63\x18\x03 \x01(\t\x12#\n\x01\x64\x18\x04 \x03(\x0b\x32\x18.AcFunDanmu.ImageCdnNode\x12#\n\x01\x65\x18\x05 \x03(\x0b\x32\x18.AcFunDanmu.ImageCdnNode\x12\t\n\x01\x66\x18\x06 \x01(\t\x12\t\n\x01g\x18\x07 \x01(\t\x12\x1d\n\x01h\x18\x08 \x01(\x0b\x32\x12.AcFunDanmu.Button\x12!\n\x01i\x18\t \x01(\x0b\x32\x16.AcFunDanmu.ClickEvent\x12\t\n\x01j\x18\n \x01(\x05\x12\t\n\x01k\x18\x0b \x01(\x03\x12\t\n\x01l\x18\x0c \x01(\x03\x12\t\n\x01m\x18\r \x01(\x05\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'CommentNotice_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMMENTNOTICE._serialized_start=88
  _COMMENTNOTICE._serialized_end=342
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: PublicGroupHit.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14PublicGroupHit.proto\x12\x1a\x41\x63\x46unDanmu.Im.Cloud.Search\"\xbe\x01\n\x0ePublicGroupHit\x12R\n\tmatchType\x18\x01 \x01(\x0e\x32?.AcFunDanmu.Im.Cloud.Search.PublicGroupHit.PublicGroupMatchType\"X\n\x14PublicGroupMatchType\x12\x10\n\x0cUNKNOWN_PGMT\x10\x00\x12\x0e\n\nGROUP_NAME\x10\x01\x12\x0c\n\x08GROUP_ID\x10\x02\x12\x10\n\x0cGROUP_NUMBER\x10\x03\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'PublicGroupHit_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PUBLICGROUPHIT._serialized_start=53
  _PUBLICGROUPHIT._serialized_end=243
  _PUBLICGROUPHIT_PUBLICGROUPMATCHTYPE._serialized_start=155
  _PUBLICGROUPHIT_PUBLICGROUPMATCHTYPE._serialized_end=243
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: GroupInfo.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import GroupBasicInfo_pb2 as GroupBasicInfo__pb2
import GroupMembersBriefInfo_pb2 as GroupMembersBriefInfo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0fGroupInfo.proto\x12\x1b\x41\x63\x46unDanmu.Im.Cloud.Message\x1a\x14GroupBasicInfo.proto\x1a\x1bGroupMembersBriefInfo.proto\"\x9e\x01\n\tGroupInfo\x12>\n\tbasicInfo\x18\x01 \x01(\x0b\x32+.AcFunDanmu.Im.Cloud.Message.GroupBasicInfo\x12Q\n\x15groupMembersBriefInfo\x18\x02 \x01(\x0b\x32\x32.AcFunDanmu.Im.Cloud.Message.GroupMembersBriefInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'GroupInfo_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GROUPINFO._serialized_start=100
  _GROUPINFO._serialized_end=258
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: B2CMerchantSessionFolderEvent.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import SessionReference_pb2 as SessionReference__pb2
import User_pb2 as User__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#B2CMerchantSessionFolderEvent.proto\x12!AcFunDanmu.Im.Cloud.SessionFolder\x1a\x16SessionReference.proto\x1a\nUser.proto\"\x89\x02\n\x1d\x42\x32\x43MerchantSessionFolderEvent\x12\'\n\x04user\x18\x01 \x01(\x0b\x32\x19.AcFunDanmu.Im.Basic.User\x12\x10\n\x08subBizId\x18\x02 \x01(\x05\x12G\n\nsessionRef\x18\x03 \x01(\x0b\x32\x33.AcFunDanmu.Im.Cloud.SessionFolder.SessionReference\x12\x17\n\x0fsessionFolderId\x18\x04 \x01(\t\x12\x0f\n\x07\x64\x65leted\x18\x05 \x01(\x08\x12\x12\n\nupdateTime\x18\x06 \x01(\x03\x12\x12\n\ncreateTime\x18\x07 \x01(\x03\x12\x12\n\nretryCount\x18\x08 \x01(\x05\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'B2CMerchantSessionFolderEvent_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _B2CMERCHANTSESSIONFOLDEREVENT._serialized_start=111
  _B2CMERCHANTSESSIONFOLDEREVENT._serialized_end=376
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: UpstreamPayload.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import FrontendInfo_pb2 as FrontendInfo__pb2
import RequsetBasicInfo_pb2 as RequsetBasicInfo__pb2
import SettingInfo_pb2 as SettingInfo__pb2
import UserInstance_pb2 as UserInstance__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15UpstreamPayload.proto\x12\x13\x41\x63\x46unDanmu.Im.Basic\x1a\x12\x46rontendInfo.proto\x1a\x16RequsetBasicInfo.proto\x1a\x11SettingInfo.proto\x1a\x12UserInstance.proto\"\x9c\x03\n\x0fUpstreamPayload\x12\x0f\n\x07\x63ommand\x18\x01 \x01(\t\x12\r\n\x05seqId\x18\x02 \x01(\x03\x12\x12\n\nretryCount\x18\x03 \x01(\r\x12\x13\n\x0bpayloadData\x18\x04 \x01(\x0c\x12\x37\n\x0cuserInstance\x18\x05 \x01(\x0b\x32!.AcFunDanmu.Im.Basic.UserInstance\x12\x11\n\terrorCode\x18\x06 \x01(\x05\x12\x35\n\x0bsettingInfo\x18\x07 \x01(\x0b\x32 .AcFunDanmu.Im.Basic.SettingInfo\x12?\n\x10requestBasicInfo\x18\x08 \x01(\x0b\x32%.AcFunDanmu.Im.Basic.RequsetBasicInfo\x12\x0e\n\x06subBiz\x18\t \x01(\t\x12\x37\n\x0c\x66rontendInfo\x18\n \x01(\x0b\x32!.AcFunDanmu.Im.Basic.FrontendInfo\x12\x0b\n\x03kpn\x18\x0b \x01(\t\x12\x16\n\x0e\x61nonymouseUser\x18\x0c \x01(\x08\x12\x0e\n\x06laneId\x18\r \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'UpstreamPayload_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _UPSTREAMPAYLOAD._serialized_start=130
  _UPSTREAMPAYLOAD._serialized_end=542
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: Emoticon.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import PicUrl_pb2 as PicUrl__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0e\x45moticon.proto\x12\x1b\x41\x63\x46unDanmu.Im.Cloud.Message\x1a\x0cPicUrl.proto\"\x83\x03\n\x08\x45moticon\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tpackageId\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x38\n\x04type\x18\x04 \x01(\x0e\x32*.AcFunDanmu.Im.Cloud.Message.Emoticon.Type\x12\x33\n\x06\x62igUrl\x18\x05 \x03(\x0b\x32#.AcFunDanmu.Im.Cloud.Message.PicUrl\x12\r\n\x05width\x18\x06 \x01(\x05\x12\x0e\n\x06height\x18\x07 \x01(\x05\x12@\n\x0c\x65moticonCode\x18\x08 \x03(\x0b\x32*.AcFunDanmu.Im.Cloud.Message.Emoticon.Code\x1a&\n\x04\x43ode\x12\x10\n\x08language\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x03(\t\"R\n\x04Type\x12\x0b\n\x07UNKNOWN\x10\x00\x12\t\n\x05\x42\x41SIC\x10\x01\x12\t\n\x05IMAGE\x10\x02\x12\x07\n\x03GIF\x10\x03\x12\x12\n\x0eSPECIAL_EFFECT\x10\x04\x12\n\n\x06SCRIPT\x10\x05\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'Emoticon_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _EMOTICON._serialized_start=62
  _EMOTICON._serialized_end=449
  _EMOTICON_CODE._serialized_start=327
  _EMOTICON_CODE._serialized_end=365
  _EMOTICON_TYPE._serialized_start=367
  _EMOTICON_TYPE._serialized_end=449
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: SessionEventReportRequest.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import EnterSession_pb2 as EnterSession__pb2
import LeaveSession_pb2 as LeaveSession__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fSessionEventReportRequest.proto\x12\x15\x41\x63\x46unDanmu.Im.Message\x1a\x12\x45nterSession.proto\x1a\x12LeaveSession.proto\"\x9e\x01\n\x19SessionEventReportRequest\x12;\n\x0c\x65nterSession\x18\x01 \x01(\x0b\x32#.AcFunDanmu.Im.Message.EnterSessionH\x00\x12;\n\x0cleaveSession\x18\x02 \x01(\x0b\x32#.AcFunDanmu.Im.Message.LeaveSessionH\x00\x42\x07\n\x05\x65ventb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'SessionEventReportRequest_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SESSIONEVENTREPORTREQUEST._serialized_start=99
  _SESSIONEVENTREPORTREQUEST._serialized_end=257
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: RemindBody.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10RemindBody.proto\x12\x15\x41\x63\x46unDanmu.Im.Message\"\xb3\x02\n\nRemindBody\x12@\n\nremindType\x18\x01 \x01(\x0e\x32,.AcFunDanmu.Im.Message.RemindBody.RemindType\x12\r\n\x05seqId\x18\x02 \x01(\x03\x12\x10\n\x08targetId\x18\x03 \x01(\x03\x12\x10\n\x08userName\x18\x04 \x01(\t\x12\x12\n\nstartIndex\x18\x05 \x01(\x05\x12\x0e\n\x06length\x18\x06 \x01(\x05\"\x8b\x01\n\nRemindType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06\x41T_ALL\x10\x01\x12\x0b\n\x07\x41T_USER\x10\x02\x12\x12\n\x0eGROUP_BULLETIN\x10\x03\x12\x13\n\x0fRECEIPT_MESSAGE\x10\x04\x12\x16\n\x12GROUP_JOIN_REQUEST\x10\x05\x12\x16\n\x12USER_MESSAGE_ALERT\x10\x06\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'RemindBody_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _REMINDBODY._serialized_start=44
  _REMINDBODY._serialized_end=351
  _REMINDBODY_REMINDTYPE._serialized_start=212
  _REMINDBODY_REMINDTYPE._serialized_end=351
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ChannelBasicInfoNotify.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import ChannelBasicInfo_pb2 as ChannelBasicInfo__pb2
import UserActionInfo_pb2 as UserActionInfo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x43hannelBasicInfoNotify.proto\x12\x1b\x41\x63\x46unDanmu.Im.Cloud.Channel\x1a\x16\x43hannelBasicInfo.proto\x1a\x14UserActionInfo.proto\"\x9f\x01\n\x16\x43hannelBasicInfoNotify\x12\x43\n\x0euserActionInfo\x18\x01 \x01(\x0b\x32+.AcFunDanmu.Im.Cloud.Channel.UserActionInfo\x12@\n\tbasicInfo\x18\x02 \x01(\x0b\x32-.AcFunDanmu.Im.Cloud.Channel.ChannelBasicInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ChannelBasicInfoNotify_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CHANNELBASICINFONOTIFY._serialized_start=108
  _CHANNELBASICINFONOTIFY._serialized_end=267
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ZtLiveUserInfo.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import ImageCdnNode_pb2 as ImageCdnNode__pb2
import ZtLiveUserIdentity_pb2 as ZtLiveUserIdentity__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14ZtLiveUserInfo.proto\x12\nAcFunDanmu\x1a\x12ImageCdnNode.proto\x1a\x18ZtLiveUserIdentity.proto\"\xb7\x01\n\x0eZtLiveUserInfo\x12\x0e\n\x06userId\x18\x01 \x01(\x03\x12\x10\n\x08nickname\x18\x02 \x01(\t\x12(\n\x06\x61vatar\x18\x03 \x03(\x0b\x32\x18.AcFunDanmu.ImageCdnNode\x12\r\n\x05\x62\x61\x64ge\x18\x04 \x01(\t\x12\x34\n\x0cuserIdentity\x18\x05 \x01(\x0b\x32\x1e.AcFunDanmu.ZtLiveUserIdentity\x12\t\n\x01\x66\x18\x06 \x01(\x08\x12\t\n\x01g\x18\x07 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ZtLiveUserInfo_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ZTLIVEUSERINFO._serialized_start=83
  _ZTLIVEUSERINFO._serialized_end=266
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: FlatMessageSearchResponse.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import MessageSearchResult_pb2 as MessageSearchResult__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x46latMessageSearchResponse.proto\x12\x1a\x41\x63\x46unDanmu.Im.Cloud.Search\x1a\x19MessageSearchResult.proto\"\x83\x01\n\x19\x46latMessageSearchResponse\x12\x45\n\x0csearchResult\x18\x01 \x03(\x0b\x32/.AcFunDanmu.Im.Cloud.Search.MessageSearchResult\x12\x0e\n\x06offset\x18\x02 \x01(\t\x12\x0f\n\x07hasMore\x18\x03 \x01(\x08\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'FlatMessageSearchResponse_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _FLATMESSAGESEARCHRESPONSE._serialized_start=91
  _FLATMESSAGESEARCHRESPONSE._serialized_end=222
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: B2CSessionListResponse.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import ChatSession_pb2 as ChatSession__pb2
import SyncCookie_pb2 as SyncCookie__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x42\x32\x43SessionListResponse.proto\x12\x15\x41\x63\x46unDanmu.Im.Message\x1a\x11\x43hatSession.proto\x1a\x10SyncCookie.proto\"\xf3\x01\n\x16\x42\x32\x43SessionListResponse\x12\x33\n\nsyncCookie\x18\x01 \x01(\x0b\x32\x1f.AcFunDanmu.Im.Basic.SyncCookie\x12\x34\n\x08sessions\x18\x02 \x03(\x0b\x32\".AcFunDanmu.Im.Message.ChatSession\x12\x14\n\x0cnotFullFetch\x18\x03 \x01(\x08\x12\x12\n\nserverTime\x18\x04 \x01(\x03\x12\x16\n\x0e\x63learLocalData\x18\x05 \x01(\x08\x12\x12\n\ncategoryId\x18\x06 \x01(\x05\x12\x18\n\x10\x63lientDataStatus\x18\x07 \x01(\x05\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'B2CSessionListResponse_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _B2CSESSIONLISTRESPONSE._serialized_start=93
  _B2CSESSIONLISTRESPONSE._serialized_end=336
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: AccessPoint.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x41\x63\x63\x65ssPoint.proto\x12\x13\x41\x63\x46unDanmu.Im.Basic\"\xf2\x01\n\x0b\x41\x63\x63\x65ssPoint\x12\x41\n\x0b\x61\x64\x64ressType\x18\x01 \x01(\x0e\x32,.AcFunDanmu.Im.Basic.AccessPoint.AddressType\x12\x0c\n\x04port\x18\x02 \x01(\r\x12\x0c\n\x04ipV4\x18\x03 \x01(\x07\x12\x0c\n\x04ipV6\x18\x04 \x01(\x0c\x12\x0e\n\x06\x64omain\x18\x05 \x01(\t\x12\x0c\n\x04quic\x18\x06 \x01(\x07\x12\x0e\n\x06quicV6\x18\x07 \x01(\x0c\"H\n\x0b\x41\x64\x64ressType\x12\t\n\x05kIPV4\x10\x00\x12\t\n\x05kIPV6\x10\x01\x12\x0b\n\x07kDomain\x10\x02\x12\t\n\x05kQuic\x10\x03\x12\x0b\n\x07kQuicV6\x10\x04\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'AccessPoint_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ACCESSPOINT._serialized_start=43
  _ACCESSPOINT._serialized_end=285
  _ACCESSPOINT_ADDRESSTYPE._serialized_start=213
  _ACCESSPOINT_ADDRESSTYPE._serialized_end=285
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: KsImDataUpdateType.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18KsImDataUpdateType.proto\x12\x1f\x41\x63\x46unDanmu.Im.Cloud.Data.Update*\x92\x02\n\x12KsImDataUpdateType\x12\x0b\n\x07INVALID\x10\x00\x12\x15\n\x11GROUP_INFO_UPDATE\x10\x01\x12\x1c\n\x18GROUP_MEMBER_LIST_UPDATE\x10\x02\x12\x11\n\rYOU_BE_KICKED\x10\x03\x12\x16\n\x12MESSAGE_READ_EVENT\x10\x04\x12\x19\n\x15MESSAGE_RECEIPT_EVENT\x10\x05\x12\x12\n\x0eSESSION_UPDATE\x10\x06\x12\x19\n\x15SESSION_FOLDER_UPDATE\x10\x07\x12\x18\n\x14\x46\x41VORITE_LIST_UPDATE\x10\x08\x12\x16\n\x12SESSION_TAG_UPDATE\x10\t\x12\x13\n\x0fMESSAGE_CLICKED\x10\nb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'KsImDataUpdateType_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _KSIMDATAUPDATETYPE._serialized_start=62
  _KSIMDATAUPDATETYPE._serialized_end=336
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['acfunsdk_ws',
 'acfunsdk_ws.blackboxprotobuf',
 'acfunsdk_ws.blackboxprotobuf.libs',
 'acfunsdk_ws.blackboxprotobuf.libs.types',
 'acfunsdk_ws.models',
 'acfunsdk_ws.models.Im',
 'acfunsdk_ws.models.Live']

package_data = \
{'': ['*'],
 'acfunsdk_ws': ['protos/*',
                 'protos/Im/Basic/*',
                 'protos/Im/Cloud/Channel/*',
                 'protos/Im/Cloud/Config/*',
                 'protos/Im/Cloud/Data/Update/*',
                 'protos/Im/Cloud/Message/*',
                 'protos/Im/Cloud/Profile/*',
                 'protos/Im/Cloud/Search/*',
                 'protos/Im/Cloud/SessionFolder/*',
                 'protos/Im/Cloud/SessionTag/*',
                 'protos/Im/Cloud/Voice/Call/*',
                 'protos/Im/Message/*',
                 'protos/zt.live.interactive/*']}

install_requires = \
['acfunsdk>=0.9.7,<0.10.0',
 'filetype>=1.1,<2.0',
 'proto-plus==1.22.1',
 'protobuf==3.20.1',
 'pycryptodome>=3.15,<4.0',
 'websocket-client>=1.4,<2.0']

setup_kwargs = {
    'name': 'acfunsdk-ws',
    'version': '0.1.3',
    'description': 'acfunsdk - websocket',
    'long_description': '# acfunSDK - websocket\n\n<br />\n\n<p align="center">\n<a href="https://github.com/dolaCmeo/acfunSDK">\n<img height="100" src="https://s3.dualstack.us-east-2.amazonaws.com/pythondotorg-assets/media/files/python-logo-only.svg" alt="">\n<img height="100" src="https://ali-imgs.acfun.cn/kos/nlav10360/static/common/widget/header/img/acfunlogo.11a9841251f31e1a3316.svg" alt="">\n</a>\n</p>\n\n<br />\n\nacfunsdk是 **非官方的 [AcFun弹幕视频网][acfun.cn]** Python库。\n\n> `acfunsdk-ws` 是`acfunsdk`的附属组件，提供websocket通信支持。\n\n- - -\n\n\n<details>\n<summary>依赖库</summary>\n\n**依赖: 包含在 `requirements.txt` 中**\n\n+ [`acfunsdk`](https://pypi.org/project/acfunsdk/)`>=0.9.7`\n\nWebSocket通信及数据处理:\n+ [`websocket-client`](https://pypi.org/project/websocket-client/)`>=1.4`\n+ [`pycryptodome`](https://pypi.org/project/pycryptodome/)`>=3.15`\n+ [`protobuf`](https://pypi.org/project/protobuf/)`==3.20.1`\n+ [`proto-plus`](https://pypi.org/project/proto-plus/)`==1.22.1`\n+ [`filetype`](https://pypi.org/project/filetype/)`>=1.1`\n\n>内置+修改: \n>\n>+ [`blackboxprotobuf`](https://pypi.org/project/blackboxprotobuf/)\n\n</details>\n\n- - -\n\n## About Me\n\n[![ac彩娘-阿部高和](https://tx-free-imgs2.acfun.cn/kimg/bs2/zt-image-host/ChQwODliOGVhYzRjMTBmOGM0ZWY1ZRCIzNcv.gif)][dolacfun]\n[♂ 整点大香蕉🍌][acfunsdk_page]\n<img alt="AcFunCard" align="right" src="https://discovery.sunness.dev/39088">\n\n- - - \n\n[dolacfun]: https://www.acfun.cn/u/39088\n[acfunsdk_page]: https://www.acfun.cn/a/ac37416587\n\n[acfun.cn]: https://www.acfun.cn/\n[Issue]: https://github.com/dolaCmeo/acfunSDK/issues\n[python]: https://www.python.org/downloads/\n[venv]: https://docs.python.org/zh-cn/3.8/library/venv.html\n',
    'author': 'dolacmeo',
    'author_email': 'dolacmeo@gmail.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://pypi.org/project/acfunsdk-ws/',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: CommonStateSignalAuthorChatCall.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import AuthorChatPlayerInfo_pb2 as AuthorChatPlayerInfo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%CommonStateSignalAuthorChatCall.proto\x12\nAcFunDanmu\x1a\x1a\x41uthorChatPlayerInfo.proto\"\x8b\x01\n\x1f\x43ommonStateSignalAuthorChatCall\x12\x14\n\x0c\x61uthorChatId\x18\x01 \x01(\t\x12\x39\n\x0finviterUserInfo\x18\x02 \x01(\x0b\x32 .AcFunDanmu.AuthorChatPlayerInfo\x12\x17\n\x0f\x63\x61llTimestampMs\x18\x03 \x01(\x03\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'CommonStateSignalAuthorChatCall_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMMONSTATESIGNALAUTHORCHATCALL._serialized_start=82
  _COMMONSTATESIGNALAUTHORCHATCALL._serialized_end=221
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: GroupMemberSettingRequest.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import SetUserAntiDisturbing_pb2 as SetUserAntiDisturbing__pb2
import SetUserNickname_pb2 as SetUserNickname__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fGroupMemberSettingRequest.proto\x12\x1b\x41\x63\x46unDanmu.Im.Cloud.Message\x1a\x1bSetUserAntiDisturbing.proto\x1a\x15SetUserNickname.proto\"\xd1\x01\n\x19GroupMemberSettingRequest\x12\x43\n\x0bsetNickname\x18\x02 \x01(\x0b\x32,.AcFunDanmu.Im.Cloud.Message.SetUserNicknameH\x00\x12O\n\x11setAntiDisturbing\x18\x03 \x01(\x0b\x32\x32.AcFunDanmu.Im.Cloud.Message.SetUserAntiDisturbingH\x00\x12\x0f\n\x07groupId\x18\x01 \x01(\tB\r\n\x0bUserSettingb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'GroupMemberSettingRequest_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GROUPMEMBERSETTINGREQUEST._serialized_start=117
  _GROUPMEMBERSETTINGREQUEST._serialized_end=326
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: CommonStateSignalPkEnd.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x43ommonStateSignalPkEnd.proto\x12\nAcFunDanmu\"\xc4\x01\n\x16\x43ommonStateSignalPkEnd\x12\t\n\x01\x61\x18\x01 \x01(\t\x12\x35\n\x01\x62\x18\x02 \x01(\x0e\x32*.AcFunDanmu.CommonStateSignalPkEnd.unknown\x12\t\n\x01\x63\x18\x03 \x01(\t\"]\n\x07unknown\x12\x05\n\x01\x64\x10\x00\x12\x05\n\x01\x65\x10\x01\x12\x05\n\x01\x66\x10\x02\x12\x05\n\x01g\x10\x03\x12\x05\n\x01h\x10\x04\x12\x05\n\x01i\x10\x05\x12\x05\n\x01j\x10\x06\x12\x05\n\x01k\x10\x07\x12\x05\n\x01l\x10\x08\x12\x05\n\x01m\x10\t\x12\x05\n\x01n\x10\n\x12\x05\n\x01o\x10\x0b\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'CommonStateSignalPkEnd_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMMONSTATESIGNALPKEND._serialized_start=45
  _COMMONSTATESIGNALPKEND._serialized_end=241
  _COMMONSTATESIGNALPKEND_UNKNOWN._serialized_start=148
  _COMMONSTATESIGNALPKEND_UNKNOWN._serialized_end=241
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ZtLiveWidgetProto.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17ZtLiveWidgetProto.proto\x12\nAcFunDanmu*\x91\x01\n\x12ZtLiveWidgetProtoA\x12\x17\n\x13ZtLiveWidgetProtoAa\x10\x00\x12\x17\n\x13ZtLiveWidgetProtoAb\x10\x01\x12\x17\n\x13ZtLiveWidgetProtoAc\x10\x02\x12\x17\n\x13ZtLiveWidgetProtoAd\x10\x03\x12\x17\n\x13ZtLiveWidgetProtoAe\x10\x04*\xaa\x01\n\x12ZtLiveWidgetProtoB\x12\x17\n\x13ZtLiveWidgetProtoBa\x10\x00\x12\x17\n\x13ZtLiveWidgetProtoBb\x10\x01\x12\x17\n\x13ZtLiveWidgetProtoBc\x10\x02\x12\x17\n\x13ZtLiveWidgetProtoBd\x10\x03\x12\x17\n\x13ZtLiveWidgetProtoBe\x10\x04\x12\x17\n\x13ZtLiveWidgetProtoBf\x10\x05*x\n\x12ZtLiveWidgetProtoC\x12\x17\n\x13ZtLiveWidgetProtoCa\x10\x00\x12\x17\n\x13ZtLiveWidgetProtoCb\x10\x01\x12\x17\n\x13ZtLiveWidgetProtoCc\x10\x02\x12\x17\n\x13ZtLiveWidgetProtoCd\x10\x03\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ZtLiveWidgetProto_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ZTLIVEWIDGETPROTOA._serialized_start=40
  _ZTLIVEWIDGETPROTOA._serialized_end=185
  _ZTLIVEWIDGETPROTOB._serialized_start=188
  _ZTLIVEWIDGETPROTOB._serialized_end=358
  _ZTLIVEWIDGETPROTOC._serialized_start=360
  _ZTLIVEWIDGETPROTOC._serialized_end=480
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: UserType.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0eUserType.proto\x12\x15\x41\x63\x46unDanmu.Im.Message*v\n\x08UserType\x12\r\n\tUT_NORMAL\x10\x00\x12\x0f\n\x0bUT_CUSTOMER\x10\x01\x12\x0f\n\x0bUT_MERCHANT\x10\x02\x12\x10\n\x0cUT_ASSISTANT\x10\x03\x12\x0f\n\x0bUT_OFFICIAL\x10\x04\x12\x16\n\tUT_UNKNOW\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'UserType_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _USERTYPE._serialized_start=41
  _USERTYPE._serialized_end=159
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: CommonNotifySignalRemoveApplyUser.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'CommonNotifySignalRemoveApplyUser.proto\x12\nAcFunDanmu\"\x97\x01\n!CommonNotifySignalRemoveApplyUser\x12\t\n\x01\x61\x18\x01 \x01(\x03\x12@\n\x01\x62\x18\x02 \x01(\x0e\x32\x35.AcFunDanmu.CommonNotifySignalRemoveApplyUser.unknown\"%\n\x07unknown\x12\x05\n\x01\x63\x10\x00\x12\x05\n\x01\x64\x10\x01\x12\x05\n\x01\x65\x10\x02\x12\x05\n\x01\x66\x10\x03\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'CommonNotifySignalRemoveApplyUser_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMMONNOTIFYSIGNALREMOVEAPPLYUSER._serialized_start=56
  _COMMONNOTIFYSIGNALREMOVEAPPLYUSER._serialized_end=207
  _COMMONNOTIFYSIGNALREMOVEAPPLYUSER_UNKNOWN._serialized_start=170
  _COMMONNOTIFYSIGNALREMOVEAPPLYUSER_UNKNOWN._serialized_end=207
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ZtLiveStartPlaySourceTypeProto.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$ZtLiveStartPlaySourceTypeProto.proto\x12\nAcFunDanmu*j\n\x1eZtLiveStartPlaySourceTypeProto\x12#\n\x1fZtLiveStartPlaySourceTypeProtoA\x10\x00\x12#\n\x1fZtLiveStartPlaySourceTypeProtoB\x10\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ZtLiveStartPlaySourceTypeProto_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ZTLIVESTARTPLAYSOURCETYPEPROTO._serialized_start=52
  _ZTLIVESTARTPLAYSOURCETYPEPROTO._serialized_end=158
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: CreateVoiceCallRequest.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import CallParam_pb2 as CallParam__pb2
import CallType_pb2 as CallType__pb2
import ChatMode_pb2 as ChatMode__pb2
import ChatTarget_pb2 as ChatTarget__pb2
import User_pb2 as User__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x43reateVoiceCallRequest.proto\x12\x1e\x41\x63\x46unDanmu.Im.Cloud.Voice.Call\x1a\x0f\x43\x61llParam.proto\x1a\x0e\x43\x61llType.proto\x1a\x0e\x43hatMode.proto\x1a\x10\x43hatTarget.proto\x1a\nUser.proto\"\xd3\x02\n\x16\x43reateVoiceCallRequest\x12\x35\n\nchatTarget\x18\x01 \x01(\x0b\x32!.AcFunDanmu.Im.Message.ChatTarget\x12:\n\x08\x63\x61llType\x18\x02 \x01(\x0e\x32(.AcFunDanmu.Im.Cloud.Voice.Call.CallType\x12:\n\x08\x63hatMode\x18\x03 \x01(\x0e\x32(.AcFunDanmu.Im.Cloud.Voice.Call.ChatMode\x12\r\n\x05\x65xtra\x18\x04 \x01(\x0c\x12<\n\tcallParam\x18\x05 \x01(\x0b\x32).AcFunDanmu.Im.Cloud.Voice.Call.CallParam\x12.\n\x0bparticipant\x18\x0b \x03(\x0b\x32\x19.AcFunDanmu.Im.Basic.User\x12\r\n\x05title\x18\x0c \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'CreateVoiceCallRequest_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CREATEVOICECALLREQUEST._serialized_start=144
  _CREATEVOICECALLREQUEST._serialized_end=483
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: PublicGroupSearchInfo.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import GroupBasicInfo_pb2 as GroupBasicInfo__pb2
import GroupJoinStatus_pb2 as GroupJoinStatus__pb2
import PublicGroupHit_pb2 as PublicGroupHit__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bPublicGroupSearchInfo.proto\x12\x1a\x41\x63\x46unDanmu.Im.Cloud.Search\x1a\x14GroupBasicInfo.proto\x1a\x15GroupJoinStatus.proto\x1a\x14PublicGroupHit.proto\"\xd8\x01\n\x15PublicGroupSearchInfo\x12\x43\n\x0egroupBasicInfo\x18\x01 \x01(\x0b\x32+.AcFunDanmu.Im.Cloud.Message.GroupBasicInfo\x12<\n\x06status\x18\x02 \x01(\x0e\x32,.AcFunDanmu.Im.Cloud.Message.GroupJoinStatus\x12<\n\x08groupHit\x18\x03 \x01(\x0b\x32*.AcFunDanmu.Im.Cloud.Search.PublicGroupHitb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'PublicGroupSearchInfo_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PUBLICGROUPSEARCHINFO._serialized_start=127
  _PUBLICGROUPSEARCHINFO._serialized_end=343
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ConfirmJoinIntoGroupNoticeMetaInfo.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import JoinRequestStatus_pb2 as JoinRequestStatus__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(ConfirmJoinIntoGroupNoticeMetaInfo.proto\x12\x1b\x41\x63\x46unDanmu.Im.Cloud.Message\x1a\x17JoinRequestStatus.proto\"\x88\x01\n\"ConfirmJoinIntoGroupNoticeMetaInfo\x12\x11\n\trequestId\x18\x01 \x01(\x03\x12\x0f\n\x07groupId\x18\x02 \x01(\t\x12>\n\x06status\x18\x03 \x01(\x0e\x32..AcFunDanmu.Im.Cloud.Message.JoinRequestStatusb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ConfirmJoinIntoGroupNoticeMetaInfo_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CONFIRMJOININTOGROUPNOTICEMETAINFO._serialized_start=99
  _CONFIRMJOININTOGROUPNOTICEMETAINFO._serialized_end=235
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: CommonStateSignalFeatureStateSync.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import LiveFeatureState_pb2 as LiveFeatureState__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'CommonStateSignalFeatureStateSync.proto\x12\nAcFunDanmu\x1a\x16LiveFeatureState.proto\"W\n!CommonStateSignalFeatureStateSync\x12\x32\n\x0c\x66\x65\x61tureState\x18\x01 \x03(\x0b\x32\x1c.AcFunDanmu.LiveFeatureStateb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'CommonStateSignalFeatureStateSync_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMMONSTATESIGNALFEATURESTATESYNC._serialized_start=79
  _COMMONSTATESIGNALFEATURESTATESYNC._serialized_end=166
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: CommonStateSignalAuthorChatChangeSoundConfig.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2CommonStateSignalAuthorChatChangeSoundConfig.proto\x12\nAcFunDanmu\"\xfa\x01\n,CommonStateSignalAuthorChatChangeSoundConfig\x12\x14\n\x0c\x61uthorChatId\x18\x01 \x01(\t\x12m\n\x15soundConfigChangeType\x18\x02 \x01(\x0e\x32N.AcFunDanmu.CommonStateSignalAuthorChatChangeSoundConfig.SoundConfigChangeType\"E\n\x15SoundConfigChangeType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0e\n\nOPEN_SOUND\x10\x01\x12\x0f\n\x0b\x43LOSE_SOUND\x10\x02\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'CommonStateSignalAuthorChatChangeSoundConfig_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMMONSTATESIGNALAUTHORCHATCHANGESOUNDCONFIG._serialized_start=67
  _COMMONSTATESIGNALAUTHORCHATCHANGESOUNDCONFIG._serialized_end=317
  _COMMONSTATESIGNALAUTHORCHATCHANGESOUNDCONFIG_SOUNDCONFIGCHANGETYPE._serialized_start=248
  _COMMONSTATESIGNALAUTHORCHATCHANGESOUNDCONFIG_SOUNDCONFIGCHANGETYPE._serialized_end=317
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: SharePlatform.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13SharePlatform.proto\x12\x13\x41\x63\x46unDanmu.Im.Basic*\xcb\x02\n\rSharePlatform\x12\x19\n\x15kSharePlatformInvalid\x10\x00\x12\x18\n\x14kSharePlatformWechat\x10\x01\x12\x1f\n\x1bkSharePlatformWechatMoments\x10\x02\x12\x14\n\x10kSharePlatformQQ\x10\x03\x12\x17\n\x13kSharePlatformQzone\x10\x04\x12\x17\n\x13kSharePlatformWeibo\x10\x05\x12\x1a\n\x16kSharePlatformKuaishou\x10\x06\x12\x1a\n\x16kSharePlatformFacebook\x10\x07\x12\x19\n\x15kSharePlatformTwitter\x10\x08\x12\x18\n\x14kSharePlatformGoogle\x10\t\x12\x17\n\x13kSharePlatformKakao\x10\n\x12\x16\n\x12kSharePlatformZalo\x10\x0b\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'SharePlatform_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SHAREPLATFORM._serialized_start=45
  _SHAREPLATFORM._serialized_end=376
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: CommonActionSignalUserShareLive.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import ZtLiveUserInfo_pb2 as ZtLiveUserInfo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%CommonActionSignalUserShareLive.proto\x12\nAcFunDanmu\x1a\x14ZtLiveUserInfo.proto\"\xb0\x01\n\x1f\x43ommonActionSignalUserShareLive\x12,\n\x08userInfo\x18\x01 \x01(\x0b\x32\x1a.AcFunDanmu.ZtLiveUserInfo\x12\x17\n\x0fsharePlatformId\x18\x02 \x01(\x05\x12\x19\n\x11sharePlatformIcon\x18\x03 \x01(\t\x12\x12\n\nsendTimeMs\x18\x04 \x01(\x03\"\x17\n\x07unknown\x12\x05\n\x01\x65\x10\x00\x12\x05\n\x01\x66\x10\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'CommonActionSignalUserShareLive_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMMONACTIONSIGNALUSERSHARELIVE._serialized_start=76
  _COMMONACTIONSIGNALUSERSHARELIVE._serialized_end=252
  _COMMONACTIONSIGNALUSERSHARELIVE_UNKNOWN._serialized_start=229
  _COMMONACTIONSIGNALUSERSHARELIVE_UNKNOWN._serialized_end=252
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ImcMessageType.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14ImcMessageType.proto\x12\x1b\x41\x63\x46unDanmu.Im.Cloud.Message*\x90\x03\n\x0eImcMessageType\x12\x08\n\x04TEXT\x10\x00\x12\t\n\x05IMAGE\x10\x01\x12\n\n\x06\x43USTOM\x10\x02\x12\t\n\x05\x41UDIO\x10\x03\x12\t\n\x05VIDEO\x10\x04\x12\x0c\n\x08\x45MOTICON\x10\x05\x12\x08\n\x04\x46ILE\x10\x06\x12\n\n\x06NOTICE\x10\n\x12\x0c\n\x08RECALLED\x10\x0b\x12\r\n\tREFERENCE\x10\x0c\x12\x11\n\rMERGE_FORWARD\x10\r\x12\x0f\n\x0bMULTI_MEDIA\x10\x0e\x12\x0e\n\nVOICE_CALL\x10\x0f\x12\x10\n\x0cPLACE_HOLDER\x10\x64\x12\x0b\n\x07REPLACE\x10\x65\x12\x10\n\x0b\x44\x45LETE_SYNC\x10\xc6\x01\x12\x17\n\x12INVISIBLE_TYPE_MAX\x10\xc7\x01\x12\x10\n\x0bRICH_NOTICE\x10\xc8\x01\x12\x15\n\x10GROUP_INVITATION\x10\xc9\x01\x12\x0f\n\nRED_PACKET\x10\xcb\x01\x12\x12\n\rCS_EVALUATION\x10\xf5\x03\x12\x10\n\x0b\x43S_QUESTION\x10\xf6\x03\x12\x15\n\x10\x43S_PICK_QUESTION\x10\xf7\x03\x12\x11\n\x0c\x43S_LIST_CARD\x10\xf8\x03\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ImcMessageType_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _IMCMESSAGETYPE._serialized_start=54
  _IMCMESSAGETYPE._serialized_end=454
# @@protoc_insertion_point(module_scope)
